@@ -23,13 +23,13 @@ class _PackagerFiles:
             "author_email": f'"{self.email}"',
             "version": f'"{self.metadata.version}"',
             "description": f'"{self.metadata.description}"',
-            "long_description": f"Path(r'{self.localrepo.get_readme_path()}').read_text()",
+            "long_description": f"Path(r'{self.localrepo.get_readme_path()}').read_text(encoding='utf-8')",
             "long_description_content_type": '"text/markdown"',
             "install_requires": self.metadata.install_requires,
             "url": f'"{self.github.url()}"',
             "license": f'"{self.license}"',
             "python_requires": f'"{", ".join([f"=={ver}.*" for ver in self.python])}"',
-            "packages": "find_namespace_packages()",
+            "packages": 'find_namespace_packages(exclude=("build*", "dist*"))',
             "extras_require": self.metadata.extras_require,
             "classifiers": self.get_classifiers(),
         }
